@@ -1,5 +1,5 @@
 package Acme::KeyboardMarathon;
-$Acme::KeyboardMarathon::VERSION = '1.20';
+$Acme::KeyboardMarathon::VERSION = '1.21';
 
 use Carp;
 use Data::Dumper;
@@ -46,13 +46,13 @@ sub new {
   return $self;
 }
 
+# split is 2m27.476s for 9.3megs of text (9754400 chars)
 sub distance {
-  my @args = @_;
-  my $self = shift @args;
+  my $self = shift @_;
   my $distance = Math::BigInt->bzero();
-  while ( my $chunk = shift @args ) {
-    croak "FAR OUT! A REFERENCE: $chunk" if ref $chunk;
-    for my $char ( split '', $chunk ) {
+  for my $i (0 .. $#_) {
+    croak "FAR OUT! A REFERENCE: $_[$i]" if ref $_[$i];
+    for my $char ( split '', $_[$i] ) {
       unless ( defined $self->{k}->{$char} ) {
         carp "WHOAH! I DON'T KNOW WHAT THIS IS: [$char] assigning it a 2.5 cm distance\n";
         $self->{k}->{$char} = 250;
@@ -64,6 +64,46 @@ sub distance {
   return $distance->bstr();
 }
 
+# substr is 2m30.419s
+#sub distance {
+#  my $self = shift @_;
+#  my $distance = Math::BigInt->bzero();
+#  for my $i (0 .. $#_) {
+#    croak "FAR OUT! A REFERENCE: $_[$i]" if ref $_[$i];
+#    my $length = length($_[$i]) - 1;
+#    for my $s ( 0 .. $length ) {
+#      my $char = substr($_[$i],$s,1);
+#      unless ( defined $self->{k}->{$char} ) {
+#        carp "WHOAH! I DON'T KNOW WHAT THIS IS: [$char] at $s assigning it a 2.5 cm distance\n";
+#        $self->{k}->{$char} = 250;
+#      }
+#      $distance += $self->{k}->{$char};
+#    }
+#  }
+#  $distance /= 100;
+#  return $distance->bstr();
+#}
+
+# Regex is 2m32.690s
+#sub distance {
+#  my $self = shift @_;
+#  my $distance = Math::BigInt->bzero();
+#  for my $i (0 .. $#_) {
+#    croak "FAR OUT! A REFERENCE: $_[$i]" if ref $_[$i];
+#    while ( $_[$i] =~ /(.)/gs ) {
+#      my $char = $1;
+#      unless ( defined $self->{k}->{$char} ) {
+#        carp "WHOAH! I DON'T KNOW WHAT THIS IS: [$char] assigning it a 2.5 cm distance\n";
+#        $self->{k}->{$char} = 250;
+#      }
+#      $distance += $self->{k}->{$char};
+#    }
+#  }
+#  $distance /= 100;
+#  return $distance->bstr();
+#}
+
+
 1;
 __END__
 
@@ -151,7 +191,7 @@ diacritics later, so I can feel better while still ignoring UTF's existence.
 
 =head1 VERSION
 
-	Acme::KeyboardMarathon v1.20 (2014/03/21)
+	Acme::KeyboardMarathon v1.21 (2014/03/21)
 
 =head1 COPYRIGHT
 
